==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/operation/RelativeThreeDViewOperationType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RelativeThreeDViewOperationType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="RelativeThreeDViewOperationType"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="First"/&gt;
 *     &lt;enumeration value="Last"/&gt;
 *     &lt;enumeration value="Next"/&gt;
 *     &lt;enumeration value="Previous"/&gt;
 *     &lt;enumeration value="Default"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "RelativeThreeDViewOperationType")
@XmlEnum
public enum RelativeThreeDViewOperationType {

    @XmlEnumValue("First")
    FIRST("First"),
    @XmlEnumValue("Last")
    LAST("Last"),
    @XmlEnumValue("Next")
    NEXT("Next"),
    @XmlEnumValue("Previous")
    PREVIOUS("Previous"),
    @XmlEnumValue("Default")
    DEFAULT("Default");
    private final String value;

    RelativeThreeDViewOperationType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static RelativeThreeDViewOperationType fromValue(String v) {
        for (RelativeThreeDViewOperationType c: RelativeThreeDViewOperationType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/RelativeThreeDViewOperationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RelativeThreeDViewOperationType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>{@code
 * <simpleType name="RelativeThreeDViewOperationType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="First"/>
 *     <enumeration value="Last"/>
 *     <enumeration value="Next"/>
 *     <enumeration value="Previous"/>
 *     <enumeration value="Default"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "RelativeThreeDViewOperationType")
@XmlEnum
public enum RelativeThreeDViewOperationType {

    @XmlEnumValue("First")
    FIRST("First"),
    @XmlEnumValue("Last")
    LAST("Last"),
    @XmlEnumValue("Next")
    NEXT("Next"),
    @XmlEnumValue("Previous")
    PREVIOUS("Previous"),
    @XmlEnumValue("Default")
    DEFAULT("Default");
    private final String value;

    RelativeThreeDViewOperationType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static RelativeThreeDViewOperationType fromValue(String v) {
        for (RelativeThreeDViewOperationType c: RelativeThreeDViewOperationType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
